==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>정말로 %1(을)를 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>바탕 화면에서 제거</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>독(dock)에서 제거</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>제거</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>바탕화면으로 보내기</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>독으로 보내기</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation>인터넷</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>채팅</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>그래픽</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>게임</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>오피스</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>읽는 중</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>개발</translation>
    </message>
    <message>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>기타</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>정말로 %1(을)를 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>모든 의존성이 함께 제거됩니다</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>컴퓨터</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>문서</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>잠그기</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>다시 시작</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>일시 정지</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>전원 종료</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>컴퓨터</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>전원 종료</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>잠그기</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>다시 시작</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>일시 정지</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation>문서</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>컴퓨터</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>수동</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정 </translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>전원 종료</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>정말로 %1(을)를 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>검색결과가 없습니다.</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>인터넷</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>채팅</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>그래픽</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>오피스</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>읽기</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>개발</translation>
    </message>
    <message>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation>기타</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>바탕 화면에서 제거</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>도크(dock)에서 제거</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>제거</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>디스플레이 크기 조정 해제하기</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>바탕화면으로 보내기</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>도크(dock)로 보내기</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>시작에서 제거하기</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>시작에 추가하기</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>모든 앱</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>인터넷</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>채팅</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>그래픽</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>게임</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>오피스</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>읽기</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>개발</translation>
    </message>
    <message>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>기타</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>컴퓨터</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>문서</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>잠그기</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>다시 시작</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>일시 정지</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>전원 종료</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>뒤로 가기</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>컴퓨터</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>전원 종료</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>잠그기</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>다시 시작</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>일시 정지</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>뒤로 가기</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>문서</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>컴퓨터</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>수동</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정 </translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>문서</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>전원</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>모든 카테고리</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>뒤로 가기</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
